@@ -104,7 +104,7 @@ let build_code args =
     | V s -> pr "int var_%d = (0 == %s);" (fresh ()) s
     | F (s,f) -> pr "size_t var_%d = (size_t)&((struct %s*)0)->%s;" (fresh ()) s f
     end args;
-  pr "int main() { return 0; }";
+  pr "int main(void) { return 0; }";
   Buffer.contents b
 
 let discover c (name,test) =
@@ -146,6 +146,12 @@ let show_c file result =
   end result;
   pr "";
   List.iter (print_include b) config_includes;
+  pr {|#if OCAML_VERSION < 50100
+#define caml_uerror uerror
+#define caml_unix_error unix_error
+#define win32_maperr caml_win32_maperr
+#endif
+|};
   pr "#include \"common.h\"";
   List.iter begin function
     | NO name ->
@@ -185,7 +191,16 @@ let show_ml file result =
   | NO name -> pr "| `%s -> false" name) result;
   close_out ch
 
-let show_ldlibs_sexp file result =
+let show_c_flags_sexp file c =
+  let cflags =
+    match C.ocaml_config_var c "ccomp_type" with
+    | Some "cc" -> ["-Wall"; "-Wextra"]
+    | Some "msvc" -> ["-W2"]
+    | _ -> []
+  in
+  C.Flags.write_sexp file cflags
+
+let show_link_flags_sexp file result =
   let ch = open_out file in
   let pr fmt = ksprintf (fun s -> output_string ch s) fmt in
   pr "(";
@@ -201,7 +216,8 @@ let main c config =
   let result = List.map (discover c) config in
   show_c "config.h" result;
   show_ml "config.ml" result;
-  show_ldlibs_sexp "ldlibs.sexp" result
+  show_c_flags_sexp "c_flags.sexp" c;
+  show_link_flags_sexp "link_flags.sexp" result
 
 let features =
   let fd_int = ND "Handle_val" in (* marker for bindings code assuming fd is represented as int *)
@@ -441,6 +457,10 @@ let features =
     "UNSHARE", L[ I"sched.h"; S "unshare"; D "CLONE_NEWPID"; D "CLONE_NEWUSER"];
     "CHROOT", L[ I"unistd.h"; S "chroot"; ];
     "SYSLOG", L[I"syslog.h"; S "syslog"; S "openlog"; S "closelog"; S "setlogmask"; D "LOG_PID"; D "LOG_CONS"; D "LOG_NDELAY"; D "LOG_ODELAY"; D "LOG_NOWAIT"; D "LOG_EMERG"; D "LOG_ALERT"; D "LOG_CRIT"; D "LOG_ERR"; D "LOG_WARNING"; D "LOG_NOTICE"; D "LOG_INFO"; D "LOG_DEBUG"];
+    "WAIT4", L[
+      I "sys/resource.h"; I "sys/time.h"; I "sys/types.h"; I "sys/wait.h";
+      DEFINE "CAML_INTERNALS"; S "wait4"
+    ];
   ]
 
 let () =
