@@ -11,7 +11,7 @@ CAMLprim value caml_extunix_posix_openpt(value flags)
 	cv_flags = extunix_open_flags(flags);
 	ret = posix_openpt(cv_flags);
 	if(ret == -1)
-		uerror("posix_openpt", Nothing);
+		caml_uerror("posix_openpt", Nothing);
 	CAMLreturn(Val_int(ret));
 }
 
@@ -19,7 +19,7 @@ CAMLprim value caml_extunix_grantpt(value fd)
 {
 	CAMLparam1(fd);
 	if(grantpt(Int_val(fd)) == -1)
-		uerror("grantpt", Nothing);
+		caml_uerror("grantpt", Nothing);
 	CAMLreturn(Val_unit);
 }
 
@@ -27,7 +27,7 @@ CAMLprim value caml_extunix_unlockpt(value fd)
 {
 	CAMLparam1(fd);
 	if(unlockpt(Int_val(fd)) == -1)
-		uerror("unlockpt", Nothing);
+		caml_uerror("unlockpt", Nothing);
 	CAMLreturn(Val_unit);
 }
 
@@ -37,7 +37,7 @@ CAMLprim value caml_extunix_ptsname(value fd)
 	CAMLlocal1(ret);
 	char *name = ptsname(Int_val(fd));
 	if(name == 0)
-		uerror("ptsname", Nothing);
+		caml_uerror("ptsname", Nothing);
 	ret = caml_copy_string(name);
 	CAMLreturn(ret);
 }
