@@ -31,15 +31,15 @@ CAMLprim value caml_extunix_renameat2(value v_oldfd, value v_oldname, value v_ne
   CAMLparam5(v_oldfd, v_oldname, v_newfd, v_newname, v_flags);
   check_flag_list(v_flags);
   int oldfd = Int_val(v_oldfd), newfd = Int_val(v_newfd);
-  const char *oldname = caml_stat_strdup(String_val(v_oldname)),
-             *newname = caml_stat_strdup(String_val(v_newname));
+  char *oldname = caml_stat_strdup(String_val(v_oldname)),
+       *newname = caml_stat_strdup(String_val(v_newname));
   int flags = caml_convert_flag_list(v_flags, rename_flags_table);
   caml_enter_blocking_section();
   int ret = renameat2(oldfd, oldname, newfd, newname, flags);
   caml_leave_blocking_section();
   caml_stat_free(oldname);
   caml_stat_free(newname);
-  if (ret != 0) uerror("renameat2", v_oldname);
+  if (ret != 0) caml_uerror("renameat2", v_oldname);
   CAMLreturn(Val_unit);
 }
 #endif
