@@ -11,7 +11,7 @@ CAMLprim value caml_extunix_setenv(value v_name, value v_val, value v_overwrite)
 
   if (0 != setenv(String_val(v_name), String_val(v_val), Bool_val(v_overwrite)))
   {
-    uerror("setenv",v_name);
+    caml_uerror("setenv",v_name);
   }
 
   CAMLreturn(Val_unit);
@@ -23,7 +23,7 @@ CAMLprim value caml_extunix_unsetenv(value v_name)
 
   if (0 != unsetenv(String_val(v_name)))
   {
-    uerror("unsetenv",v_name);
+    caml_uerror("unsetenv",v_name);
   }
 
   CAMLreturn(Val_unit);
@@ -38,7 +38,7 @@ CAMLprim value caml_extunix_clearenv(value v_unit)
   UNUSED(v_unit);
   if (0 != clearenv())
   {
-    uerror("clearenv", Nothing);
+    caml_uerror("clearenv", Nothing);
   }
 
   return Val_unit;
